emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/hyperbole 390a976 01/20: * hload-path.el (hyperb:dir):


From: Robert Weiner
Subject: [elpa] externals/hyperbole 390a976 01/20: * hload-path.el (hyperb:dir): If the Emacs Package Manager has already added this
Date: Tue, 9 Aug 2016 19:17:07 +0000 (UTC)

branch: externals/hyperbole
commit 390a9764249335e24fa14c477dc799129213dbfc
Author: Bob Weiner <address@hidden>
Commit: Bob Weiner <address@hidden>

    * hload-path.el (hyperb:dir): If the Emacs Package Manager has already 
added this
        to load-path without a trailing directory separator, don't add it with 
one.
---
 ChangeLog     |    9 +++++++++
 hload-path.el |    9 ++++++---
 2 files changed, 15 insertions(+), 3 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index 87cbbf0..6271540 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,14 @@
 -- Almost all changes listed herein are new as of 2016. --
 
+2016-07-27  Bob Weiner  <address@hidden>
+
+* hload-path.el (hyperb:dir): If the Emacs Package Manager has already added 
this
+    to load-path without a trailing directory separator, don't add it with one.
+
+==============================================================================
+V6.0.2 changes ^^^^:
+==============================================================================
+
 2016-07-26  Mats Lidell  <address@hidden>
 
 * hypb.el (hypb:rgrep-command): Removed -Z option.
diff --git a/hload-path.el b/hload-path.el
index 60df85e..db6b3c5 100644
--- a/hload-path.el
+++ b/hload-path.el
@@ -51,8 +51,11 @@
   "Directory where the Hyperbole executable code is kept.
 It must end with a directory separator character.")
 
-;; Add hyperb:dir to load-path so other Hyperbole libraries can be found.
-(add-to-list 'load-path hyperb:dir)
+;; Add hyperb:dir to load-path so other Hyperbole libraries can be
+;; found unless it is already there since the Emacs Package Manager
+;; may have already added it.
+(unless (member (directory-file-name hyperb:dir) load-path)
+  (add-to-list 'load-path hyperb:dir))
 
 ;;; ************************************************************************
 ;;; Koutliner mode and file suffix importation settings
@@ -62,7 +65,7 @@ It must end with a directory separator character.")
 ;; initializations.
 
 (if hyperb:kotl-p
-    (progn (add-to-list #'load-path (expand-file-name "kotl/" hyperb:dir))
+    (progn (add-to-list 'load-path (expand-file-name "kotl/" hyperb:dir))
           ;; Invoke kotl-mode for files ending in ".kotl".  Also
           ;; allow ".kot" for DOS and Windows users.
           (setq auto-mode-alist (cons '("\\.kotl$\\|\\.kot$" . kotl-mode)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]